@@ -188,8 +188,7 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
     //drawsd=0; //(1-draws)*(1-drawMuTau);
 
   Rcpp::NumericMatrix mdraws(nd, n), //sdraws(nd, pow(n, draws)),
-    sdraws(nd, n), mpred(nd, np), spred(nd, np), zdraws(nd, n); 
-    //zdraws(nd+burn, n), edraws(nd+burn, n);
+    sdraws(nd, n), mpred(nd, np), spred(nd, np); // zdraws(nd, n); 
   //Rcpp::NumericVector sddraws((nd+burn)*drawsd);
 
   // for varcounts
@@ -282,8 +281,8 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
   //--------------------------------------------------
   //print args
   //  Rprintf("**********************\n");
-  Rprintf("n: %ld\n",n);
-  Rprintf("pf, ps: %ld, %ld\n",pf, ps);
+  Rprintf("n: %d\n",(int)n);
+  Rprintf("pf, ps: %d, %d\n",(int)pf,(int)ps);
   Rprintf("xftrain first row: %lf, %lf\n",xftrain[0],xftrain[pf-1]);
 //  Rprintf("xftrain second row: %lf, %lf\n",xftrain[pf],xftrain[2*pf-1]);
   Rprintf("xftrain last row: %lf, %lf\n",xftrain[(n-1)*pf],xftrain[n*pf-1]);
@@ -292,7 +291,7 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
   Rprintf("xstrain last row: %lf, %lf\n",xstrain[(n-1)*ps],xstrain[n*ps-1]);
   Rprintf("first and last y: %lf, %lf\n",y[0],y[n-1]);
   if(np) {
-    Rprintf("np: %d\n",np);
+    Rprintf("np: %d\n",(int)np);
     Rprintf("xftest first row xftest: %lf, %lf\n",xftest[0],xftest[pf-1]);
 //    Rprintf("xftest second row xftest: %lf, %lf\n",xftest[pf],xftest[2*pf-1]);
     Rprintf("xftest last row xftest : %lf, %lf\n",xftest[(np-1)*pf],xftest[np*pf-1]);
@@ -302,20 +301,20 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
   } else {
     Rprintf("no test observations\n");
   }
-  Rprintf("number of trees mean: %ld\n",m);
-  Rprintf("number of trees stan dev: %ld\n",mh);
+  Rprintf("number of trees mean: %d\n",(int)m);
+  Rprintf("number of trees stan dev: %d\n",(int)mh);
   Rprintf("tau: %lf\n",tau);
   Rprintf("total.lambda, lambda: %lf, %lf\n",overalllambda, lambda);
   Rprintf("total.nu, nu: %lf, %lf\n",overallnu, nu);
-  Rprintf("burn (nskip): %ld\n",burn);
-  Rprintf("nd (ndpost): %ld\n",nd);
-  Rprintf("nadapt: %ld\n",nadapt);
-  Rprintf("adaptevery: %ld\n",adaptevery);
+  Rprintf("burn (nskip): %d\n",(int)burn);
+  Rprintf("nd (ndpost): %d\n",(int)nd);
+  Rprintf("nadapt: %d\n",(int)nadapt);
+  Rprintf("adaptevery: %d\n",(int)adaptevery);
   Rprintf("mean tree prior base: %lf\n",falpha);
   Rprintf("mean tree prior power: %lf\n",mybeta);
   Rprintf("variance tree prior base: %lf\n",salpha);
   Rprintf("variance tree prior power: %lf\n",mybetah);
-  Rprintf("thread count: %ld\n",tc);
+  Rprintf("thread count: %d\n",tc);
 //Rprintf("first and last sigmav: %lf, %lf\n",sigmav[0],sigmav[n-1]);
   Rprintf("chgvf first row: %lf, %lf\n",chgvf[0][0],chgvf[0][pf-1]);
   Rprintf("chgvf last row: %lf, %lf\n",chgvf[pf-1][0],chgvf[pf-1][pf-1]);
@@ -329,8 +328,8 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
   Rprintf("variance trees initial step width pert move: %lf\n",stepwperth);
   Rprintf("mean trees prob of a change var move : %lf\n",probchv);
   Rprintf("variance trees prob of a change var move : %lf\n",probchvh);
-  Rprintf("mean trees min num obs in bottom node: %ld\n",minnumbot);
-  Rprintf("variance trees min num obs in bottom node: %ld\n",minnumboth);
+  Rprintf("mean trees min num obs in bottom node: %d\n",(int)minnumbot);
+  Rprintf("variance trees min num obs in bottom node: %d\n",(int)minnumboth);
 //  Rprintf("sigma prior : alphao=%lf, betao=%lf\n", alphao, betao);
   //Rprintf("base prior : muo=%lf, ko=%lf, alphao=%lf, betao=%lf\n",
   // muo, ko, alphao, betao);
@@ -351,7 +350,7 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
   Rprintf("alpha draw: alpha_a=%lf, alpha_b=%lf\n", 
 	  Rcpp::as<double>(prior["alpha.a"]),
 	  Rcpp::as<double>(prior["alpha.b"]));
-  Rprintf("draw: DPM=%ld, constrain=%ld\n", drawMuTau, constrain);
+  Rprintf("draw: DPM=%d, constrain=%d\n", drawMuTau, constrain);
   //Rprintf("draw: s=%ld, MuTau=%ld\n", draws, drawMuTau);
 /*
   if(impute_flag) {
@@ -360,7 +359,7 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
 	 << ',' << "index n-1=" << impute_prior[n-1] << endl;
   }
 */
-  Rprintf("printevery: %d\n",printevery);
+  Rprintf("printevery: %d\n",(int)printevery);
 
   //--------------------------------------------------
   //make xinfo
@@ -583,25 +582,14 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
 	    z[k]=censor[k]*gen.rtnorm(censor[k]*y[k], 
 				       censor[k]*ambm.f(k), sig[k]);
 	}
-
-/*
-	if(drawrho && !adapting) {
-	  if(z[k]>zdraws2(h, k)) z[k]=zdraws2(h, k);
-	}
-*/
       }
 /*
-      e[k]=z[k];
-      if(keeping || burning) {
-	zdraws(h, k)=z[k];
-	if(drawrho) sig[k] *= pow(1.-pow(rho, 2.), 0.5);
-      }
-*/
       if(keeping) {
 	if(drawDP) zdraws(j, k)=gen.normal(phi(g, 0)*sig[k]+ambm.f(k), 
 					   pow(phi(g, 1), -0.5)*sig[k]);
 	else zdraws(j, k)=gen.normal(ambm.f(k), sig[k]);
       }
+*/
     }
 
     for(size_t k=0;k<n;k++) {
@@ -866,9 +854,7 @@ double nu=2./(1.-pow(1.-2/overallnu, opm));
     ret["s.test"]=spred;
   }
 
-  ret["z.train"]=zdraws;
-  //ret["e.train"]=edraws;
-  //if(drawrho) ret["rho"]=rhodraws;
+  //ret["z.train"]=zdraws;
 
   // summary statistics
   if(summarystats) {
